import { ICryptoUtils } from "@snickerdoodlelabs/node-utils";
import { ConsentContractError, EVMAccountAddress, EVMContractAddress, IpfsCID, Signature, TokenId, RequestForData, BlockNumber, DomainName, BaseURI, HexString, InvalidParametersError, BigNumberString, BlockchainCommonErrors, Commitment } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { IConsentContract } from "../interfaces/IConsentContract.js";
import { WrappedTransactionResponse, EConsentRoles, Tag, ContractOverrides } from "../interfaces/index.js";
export declare class ConsentContract extends ERC7529Contract<ConsentContractError> implements IConsentContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    protected cryptoUtils: ICryptoUtils;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress, cryptoUtils: ICryptoUtils);
    getContractAddress(): EVMContractAddress;
    optIn(commitment: Commitment, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    restrictedOptIn(commitment: Commitment, nonce: TokenId, signature: Signature, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    requestForData(ipfsCID: IpfsCID, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    queryFilter(eventFilter: ethers.ContractEventName, fromBlock?: BlockNumber, toBlock?: BlockNumber): ResultAsync<(ethers.EventLog | ethers.Log)[], ConsentContractError | BlockchainCommonErrors>;
    addDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    removeDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    getDomain(domain: DomainName): ResultAsync<boolean, ConsentContractError | BlockchainCommonErrors>;
    getRequestForDataListByRequesterAddress(requesterAddress: EVMAccountAddress, fromBlock?: BlockNumber, toBlock?: BlockNumber): ResultAsync<RequestForData[], ConsentContractError | BlockchainCommonErrors>;
    getRequestForDataList(fromBlock?: BlockNumber, toBlock?: BlockNumber): ResultAsync<RequestForData[], ConsentContractError | BlockchainCommonErrors>;
    disableOpenOptIn(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    enableOpenOptIn(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    baseURI(): ResultAsync<BaseURI, ConsentContractError | BlockchainCommonErrors>;
    setBaseURI(baseUri: BaseURI, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    hasRole(role: EConsentRoles, address: EVMAccountAddress): ResultAsync<boolean, ConsentContractError | BlockchainCommonErrors>;
    grantRole(role: EConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    revokeRole(role: EConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    renounceRole(role: EConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    getQueryHorizon(): ResultAsync<BlockNumber, ConsentContractError | BlockchainCommonErrors>;
    setQueryHorizon(blockNumber: BlockNumber, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    estimateGasLimitForSetQueryHorizon(blockNumber: BlockNumber, overrides?: ContractOverrides): ResultAsync<BigNumberString, BlockchainCommonErrors | ConsentContractError>;
    checkCommitments(commitments: Commitment[]): ResultAsync<number[], ConsentContractError | BlockchainCommonErrors>;
    checkNonces(nonces: TokenId[]): ResultAsync<boolean[], ConsentContractError | BlockchainCommonErrors>;
    fetchAnonymitySet(start: BigNumberString, stop: BigNumberString): ResultAsync<Commitment[], BlockchainCommonErrors | ConsentContractError>;
    totalSupply(): ResultAsync<number, ConsentContractError | BlockchainCommonErrors>;
    openOptInDisabled(): ResultAsync<boolean, ConsentContractError | BlockchainCommonErrors>;
    getStakingToken(): ResultAsync<EVMContractAddress, ConsentContractError | BlockchainCommonErrors>;
    tagIndices(tag: string): ResultAsync<BigNumberString, ConsentContractError | BlockchainCommonErrors>;
    updateMaxTagsLimit(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError | BlockchainCommonErrors>;
    getNumberOfStakedTags(): ResultAsync<number, ConsentContractError | BlockchainCommonErrors>;
    getTagArray(): ResultAsync<Tag[], ConsentContractError | BlockchainCommonErrors>;
    newGlobalTag(tag: string, stakingToken: EVMContractAddress, stakeOWner: EVMAccountAddress | EVMContractAddress, newStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    newLocalTagUpstream(tag: string, stakingToken: EVMContractAddress, stakeOwner: EVMAccountAddress | EVMContractAddress, newStakeAmount: BigNumberString, existingStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    newLocalTagDownstream(tag: string, stakingToken: EVMContractAddress, stakeOwner: EVMAccountAddress | EVMContractAddress, existingStakeAmount: BigNumberString, newStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    moveExistingListingUpstream(tag: string, stakingToken: EVMContractAddress, stakeOwner: EVMAccountAddress | EVMContractAddress, newStakeAmount: BigNumberString, existingStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    restakeExpiredListing(tag: string, stakingToken: EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    replaceExpiredListing(tag: string, stakingToken: EVMContractAddress, stakeOwner: EVMAccountAddress | EVMContractAddress, stakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    removeListing(tag: string, stakingToken: EVMContractAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ConsentContractError>;
    getSignature(values: (string | EVMAccountAddress | bigint | HexString | EVMContractAddress)[]): ResultAsync<Signature, InvalidParametersError>;
    filters: {
        Transfer: (fromAddress: EVMAccountAddress | null, toAddress: EVMAccountAddress | null) => ethers.DeferredTopicFilter;
        RequestForData: (ownerAddress: EVMAccountAddress) => ethers.DeferredTopicFilter;
        RequestForDataNoOwner: () => ethers.DeferredTopicFilter;
    };
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): ConsentContractError;
}
//# sourceMappingURL=ConsentContract.d.ts.map