import { EVMAccountAddress, EVMContractAddress, TokenUri, TokenId, BaseURI, ONFT721RewardContractError, BlockchainCommonErrors, DomainName } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { ResultAsync } from "neverthrow";
import { BaseContract } from "../implementations/BaseContract.js";
import { IEthersContractError } from "../implementations/BlockchainErrorMapper.js";
import { ERewardRoles } from "../interfaces/enums/ERewardRoles.js";
import { ContractOverrides, IONFT721RewardContract, WrappedTransactionResponse } from "../interfaces/index.js";
export declare class ONFT721RewardContract extends BaseContract<ONFT721RewardContractError> implements IONFT721RewardContract {
    protected providerOrSigner: ethers.Provider | ethers.Signer;
    protected contractAddress: EVMContractAddress;
    constructor(providerOrSigner: ethers.Provider | ethers.Signer, contractAddress: EVMContractAddress);
    getContractAddress(): EVMContractAddress;
    getOwner(): ResultAsync<EVMAccountAddress, ONFT721RewardContractError | BlockchainCommonErrors>;
    getDefaultAdminRoleMembers(): ResultAsync<EVMAccountAddress[], ONFT721RewardContractError | BlockchainCommonErrors>;
    getMinterRoleMembers(): ResultAsync<EVMAccountAddress[], ONFT721RewardContractError | BlockchainCommonErrors>;
    baseURI(): ResultAsync<BaseURI, ONFT721RewardContractError | BlockchainCommonErrors>;
    setBaseURI(baseUri: BaseURI, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    balanceOf(address: EVMAccountAddress): ResultAsync<number, ONFT721RewardContractError | BlockchainCommonErrors>;
    ownerOf(tokenId: TokenId): ResultAsync<EVMAccountAddress, ONFT721RewardContractError | BlockchainCommonErrors>;
    tokenURI(tokenId: TokenId): ResultAsync<TokenUri | null, ONFT721RewardContractError | BlockchainCommonErrors>;
    hasRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress): ResultAsync<boolean, ONFT721RewardContractError | BlockchainCommonErrors>;
    grantRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    revokeRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    renounceRole(role: keyof typeof ERewardRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    addDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    removeDomain(domain: DomainName, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    checkDomain(domain: DomainName): ResultAsync<boolean, ONFT721RewardContractError | BlockchainCommonErrors>;
    isApprovedForAll(tokenOwnerAddress: EVMAccountAddress, operatorToApprove: EVMAccountAddress): ResultAsync<boolean, ONFT721RewardContractError | BlockchainCommonErrors>;
    setApproveForAll(addressToApprove: EVMAccountAddress, approved: boolean, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    safeTransferFrom(from: EVMAccountAddress, to: EVMAccountAddress, tokenId: TokenId, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, BlockchainCommonErrors | ONFT721RewardContractError>;
    protected generateContractSpecificError(msg: string, e: IEthersContractError, transaction: ethers.Transaction | null): ONFT721RewardContractError;
    filters: {
        Transfer: (fromAddress: EVMAccountAddress | null, toAddress: EVMAccountAddress | null) => ethers.DeferredTopicFilter;
    };
}
//# sourceMappingURL=ONFT721RewardContract.d.ts.map